@@ -34,8 +34,7 @@ sub get_config_file ()
     "redhat-7.3"      => "redhat-6.2",
     "redhat-8.0"      => "redhat-6.2",
     "mandrake-9.0"    => "redhat-6.2",
-    "debian-3.0"      => "redhat-6.2",
-    "ubuntu-7.04"     => "redhat-6.2",
+    "debian"          => "redhat-6.2",
     "suse-9.0"        => "redhat-6.2",
     "slackware-9.1.0" => "redhat-6.2",
     "gentoo"          => "redhat-6.2",
@@ -151,9 +150,14 @@ sub apply_ntp_date
       $servers .= " $server";
   }
 
+  if ($server eq "") {
+      # There are no servers, pick them from the ntp.org pool
+      $server = "0.pool.ntp.org 1.pool.ntp.org 2.pool.ntp.org";
+  }
+
   # run ntpdate, this will only be effective
   # when there isn't any NTP server running
-  &Utils::File::run ("ntpdate -b $servers") if ($servers);
+  &Utils::File::run ("ntpdate", "-b", $servers) if ($servers);
 }
 
 sub get
